package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Jul 9, 2021
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Provider interface {
ReadToken(tokenStr string, bean interface{}) (subject string, err error)
MaskToken(subject string, bean interface{}) (signed string, err error)
}
Provider jwt配置加载,token生成和读取
Source Files
¶
Click to show internal directories.
Click to hide internal directories.